@@ -18,7 +18,7 @@ restxml_unmarshal_meta <- function(request) {
 restxml_unmarshal <- function(request) {
   t <- rest_payload_type(request$data)
   if (t == "structure" || t == "") {
-    data <- decode_xml(request$http_response$body)
+    data <- request$http_response$body
     interface <- request$data
     result_name <- paste0(request$operation$name, "Result")
     request$data <- xml_unmarshal(data, interface, result_name)
